###DATAVERSE REPLICATION FILE - THE RETURNS TO OFFICE IN A "RUBBER STAMP" PARLIAMENT (R Analysis File)###
##Rory Truex, Ph.D. Candidate, Yale University Department of Political Science, rory.truex@yale.edu##

##LOAD PACKAGES##
setwd('/Users/rorytruex/Dropbox/Returns to Office Project')
rm(list=ls(all=TRUE))

library("arm")
library("foreign")

##LOAD DATA FOR FIGURES##
rto.figure1.data <- read.dta("Dataverse Replication File - RTO Trim CS Data.dta", convert.underscore = TRUE)
rto.figure2.data <- read.csv(file="/Users/rorytruex/Dropbox/Returns to Office Project/RTOFigure2Data.csv",head=TRUE,sep=",")
rto.figure3.data <- read.csv(file="/Users/rorytruex/Dropbox/Returns to Office Project/RTOFigure3Data.csv",head=TRUE,sep=",")
rto.figure4.data <- read.csv(file="/Users/rorytruex/Dropbox/Returns to Office Project/RTOFigure4Data.csv",head=TRUE,sep=",")



##ANALYSIS FIGURES##

#Figure 1: Understanding NPC Selection Processes#
pdf("rto.fig1.pdf", width=8, height=9)
par(cex.axis=1.25)
par(cex.lab=1.25)
par(cex.main=1.25)
par (mfcol=c(2,2))
plot(density(rto.figure1.data$roa2007[rto.figure1.data$npc==1], bw="nrd0", adjust=.75), lty=4, lwd=2, col="grey20", xlab = "Return on Assets (2007)", ylab = "Density", main = "Return on Assets", xlim=c(-.3,.3),ylim=c(0,12))
lines(density(rto.figure1.data$roa2007[rto.figure1.data$npc==0], bw="nrd0", adjust=.75), lty=1, lwd=2, col="grey85")
legend("topright",c("NPC","Non-NPC"),lwd=c(2), lty = c(4,1), col=c("grey20","grey85"), box.lwd=0, cex=.85, bty="n")

plot(density(rto.figure1.data$rev2007[rto.figure1.data$npc==1], bw="nrd0", adjust=.75), lty=4, lwd=2, col="grey20", xlab = "Revenue (2007)", ylab = "Density", main = "Revenue", xlim=c(0,85000), ylim=c(0,0.0004))
lines(density(rto.figure1.data$rev2007[rto.figure1.data$npc==0], bw="nrd0", adjust=.75), lty=1, lwd=2, col="grey85")
legend("topright",c("NPC","Non-NPC"),lwd=c(2), lty = c(4,1), col=c("grey20","grey85"), box.lwd=0, cex=.85, bty="n")

plot(density(rto.figure1.data$margin2007[rto.figure1.data$npc==1], bw="nrd0", adjust=.75), lty=4, lwd=2, col="grey20", xlab = "Operating Profit Margin (2007)", ylab = "Density", main = "Operating Profit Margin", xlim=c(-.75,.75),ylim=c(0,6))
lines(density(rto.figure1.data$margin2007[rto.figure1.data$npc==0], bw="nrd0", adjust=.75), lty=1, lwd=2, col="grey85")
legend("topright",c("NPC","Non-NPC"),lwd=c(2), lty = c(4,1), col=c("grey20","grey85"), box.lwd=0, cex=.85, bty="n")

plot(density(rto.figure1.data$so.portion[rto.figure1.data$npc==1], bw="nrd0", adjust=.75), lty=4, lwd=2, col="grey20", xlab = "State Owned Portion (2007)", ylab = "Density", main = "Ownership", xlim=c(0,1),ylim=c(0,4))
lines(density(rto.figure1.data$so.portion[rto.figure1.data$npc==0], bw="nrd0", adjust=.75), lty=1, lwd=2, col="grey85")
legend("topright",c("NPC","Non-NPC"),lwd=c(2), lty = c(4,1), col=c("grey20","grey85"), box.lwd=0, cex=.85, bty="n")
dev.off()


#Figure 2: Effects of NPC Membership on Key Financial Indicators#
pdf("rto.fig2.pdf", width=8.25, height=11)
par(mfcol=c(2,1))
par(cex.axis=1.25)
par(cex.lab=1.25)
par(cex.main=1.25)

plot(rto.figure2.data$year,rto.figure2.data$roa.npc, type = "l", col="grey20", lty=2, ylab = "Mean Return on Assets", lwd=3, ylim=c(-.02,.085), xlab = "Year End", main= "NPC Membership and Return on Assets")
lines(rto.figure2.data$year, rto.figure2.data$roa.non, lty=3, lwd=3, col="grey50")
lines(rto.figure2.data$year, rto.figure2.data$roa.nonunw, lty=1, lwd=2, col="grey85")
segments(rto.figure2.data$year, rto.figure2.data$roa.l95, rto.figure2.data$year, rto.figure2.data$roa.u95, lwd=1.25)
points(rto.figure2.data$year, rto.figure2.data$roa.diff, pch=15, col="black", cex=1.25)
abline(h=0,lty=1,lwd=.25)
legend("topright",c("NPC","Non-NPC (weighted)", "Non-NPC (unweighted)","NPC - Non-NPC (weighted)"),lwd=c(3,3,2,.65), lty = c(2,3,1,1), pch=c(NA,NA,NA,15), col=c("grey20","grey50","grey85","black"), bty="n", box.lwd=0, cex=.85)

plot(rto.figure2.data$year,rto.figure2.data$op.npc, type = "l", col="grey20", lty=2, ylab = "Mean Operating Profit Margin", lwd=3, ylim=c(-.05,.18), xlab = "Year End", main= "NPC Membership and Operating Profit Margin")
lines(rto.figure2.data$year, rto.figure2.data$op.non, lty=3, lwd=3, col="grey50")
lines(rto.figure2.data$year, rto.figure2.data$op.nonunw, lty=1, lwd=2, col="grey85")
segments(rto.figure2.data$year, rto.figure2.data$op.l95, rto.figure2.data$year, rto.figure2.data$op.u95, lwd=1.25)
points(rto.figure2.data$year, rto.figure2.data$op.diff, pch=15, col="black", cex=1.25)
abline(h=0,lty=1,lwd=.25)
legend("topright",c("NPC","Non-NPC (weighted)", "Non-NPC (unweighted)","NPC - Non-NPC (weighted)"),lwd=c(3,3,2, .65), lty = c(2,3,1, 1), pch=c(NA,NA,NA,15), col=c("grey20","grey50","grey85", "black"), bty="n", box.lwd=0, cex=.85)
dev.off()


#Figure 3: Conditioning Effect on State-ownership and Revenue#
pdf("rto.fig3.pdf", width=9.0, height=9.0)
par(mfcol=c(2,2))
par(cex.axis=1.25)
par(cex.lab=1.25)
par(cex.main=1.25)
plot(rto.figure3.data$so_portion,rto.figure3.data$so.roa.effect, type = "l", col="black", lty=1, xlim=c(0,1), ylim=c(-.05,.05), ylab = "Marginal Effect of NPC Membership", lwd=2, xlab="State-owned Portion",main= "Return on Assets")
lines(rto.figure3.data$so_portion,rto.figure3.data$so.roa.uci, lty=2, lwd=1, col="black")
lines(rto.figure3.data$so_portion,rto.figure3.data$so.roa.lci, lty=2, lwd=1, col="black")
legend("bottomleft",c("Marginal Effect","95% Confidence Interval"),lwd=c(2,1), lty = c(1,2), bty="n", box.lwd=0, cex=.85)
abline(h=0)

plot(rto.figure3.data$so_portion,rto.figure3.data$so.margin.effect, type = "l", col="black", lty=1, xlim=c(0,1), ylim=c(-.08,.08), ylab = "Marginal Effect of NPC Membership", lwd=2, xlab="State-owned Portion",main= "Operating Profit Margin")
lines(rto.figure3.data$so_portion,rto.figure3.data$so.margin.uci, lty=2, lwd=1, col="black")
lines(rto.figure3.data$so_portion,rto.figure3.data$so.margin.lci, lty=2, lwd=1, col="black")
legend("bottomleft",c("Marginal Effect","95% Confidence Interval"),lwd=c(2,1), lty = c(1,2), bty="n", box.lwd=0, cex=.85)
abline(h=0)

plot(rto.figure3.data$rev2007,rto.figure3.data$rev2007.roa.effect, type = "l", col="black", lty=1, xlim=c(0,50000), ylim=c(-.05,.05), ylab = "Marginal Effect of NPC Membership", lwd=2, xlab="Revenue (2007)",main= "Return on Assets")
lines(rto.figure3.data$rev2007,rto.figure3.data$rev2007.roa.uci, lty=2, lwd=1, col="black")
lines(rto.figure3.data$rev2007,rto.figure3.data$rev2007.roa.lci, lty=2, lwd=1, col="black")
legend("bottomleft",c("Marginal Effect","95% Confidence Interval"),lwd=c(2,1), lty = c(1,2), bty="n", box.lwd=0, cex=.85)
abline(h=0)

plot(rto.figure3.data$rev2007,rto.figure3.data$rev2007.margin.effect, type = "l", col="black", lty=1, xlim=c(0,50000), ylim=c(-.08,.08), ylab = "Marginal Effect of NPC Membership", lwd=2, xlab="Revenue (2007)",main= "Operating Profit Margin")
lines(rto.figure3.data$rev2007,rto.figure3.data$rev2007.margin.uci, lty=2, lwd=1, col="black")
lines(rto.figure3.data$rev2007,rto.figure3.data$rev2007.margin.lci, lty=2, lwd=1, col="black")
legend("bottomleft",c("Marginal Effect","95% Confidence Interval"),lwd=c(2,1), lty = c(1,2), bty="n", box.lwd=0, cex=.85)
abline(h=0)
dev.off()


#Figure 4: Testing the External Perceptions Mechanism#
pdf("rto.fig4.pdf", width=8.25, height=5.5)
par(mfcol=c(1,1))
par(cex.axis=1.25)
par(cex.lab=1.25)
par(cex.main=1.25)
plot(rto.figure4.data$week,rto.figure4.data$price.npc, type = "l", col="grey20", lty=2, xaxt='n', ylab = "Stock Price (RMB)", lwd=3, xlab="", ylim=c(15,35), main= "NPC Membership and Stock Prices")
lines(rto.figure4.data$week, rto.figure4.data$price.nonnpc.w4, lty=3, lwd=3, col="grey50")
lines(rto.figure4.data$week, rto.figure4.data$price.nonnpc.unweighted, lty=1, lwd=2, col="grey85")
axis(1, at=rto.figure4.data$week, labels=rto.figure4.data$date, las=2, cex=.8)
legend("topleft",c("NPC","Non-NPC (weighted)", "Non-NPC (unweighted)"),lwd=c(3,3,2), lty = c(2,3,1), pch=c(NA,NA,NA), col=c("grey20","grey50","grey85"), bty="n", box.lwd=0, cex=.85)
rect(8, 15, 16, 35, angle = 45,
     col = NA, border = NULL, lwd=3)
text(12,24.5,"NPC Membership Revealed", cex=1)
dev.off()

