***DATAVERSE REPLICATION FILE - THE RETURNS TO OFFICE IN A "RUBBER STAMP" PARLIAMENT (Stata Analysis File)***
**Rory Truex, Ph.D. Candidate, Yale University Department of Political Science, rory.truex@yale.edu**

**Load Cross-section Data**
use "/Users/rorytruex/Dropbox/Returns to Office Project/Dataverse Replication File - RTO Trim CS Data.dta"

**Run Entropy Balancing Model**

*W1*
ebalance npc price2007 roa2007 margin2007 rev2007, targets(1) maxiter(1000) gen(weights_w1)

*W2*
ebalance npc price2007 roa2007 roa2006 roa2005 margin2007 margin2006 margin2005 rev2007 rev2006 rev2005, targets(1) maxiter(1000) gen(weights_w2)

*W3*
ebalance npc price2007 roa2007 roa2006 roa2005 margin2007 margin2006 margin2005 rev2007 rev2006 rev2005 so_portion gind_ind* debtratio2007, targets(1) maxiter(1000) gen(weights_w3)

*W4* [Reported in Table 3: Results of Entropy Balancing]
ebalance npc price2007 roa2007 roa2006 roa2005 margin2007 margin2006 margin2005 rev2007 rev2006 rev2005 so_portion gind_ind* debtratio2007 shares2007 txpd2007 firmage, targets(1) maxiter(1000) gen(weights_w4)


**Calculate Mean ROA and MARGIN for Figure 2** [See "RTOFigure2Data.csv"]

svyset [pweight=weights_w4]

svy: mean roa2005, over(npc)
lincom [roa2005]1 - [roa2005]0
svy: mean roa2006, over(npc)
lincom [roa2006]1 - [roa2006]0
svy: mean roa2007, over(npc)
lincom [roa2007]1 - [roa2007]0
svy: mean roa2008, over(npc)
lincom [roa2008]1 - [roa2008]0
svy: mean roa2009, over(npc) 
lincom [roa2009]1 - [roa2009]0
svy: mean roa2010, over(npc)
lincom [roa2010]1 - [roa2010]0

svy: mean margin2005, over(npc)
lincom [margin2005]1 - [margin2005]0
svy: mean margin2006, over(npc)
lincom [margin2006]1 - [margin2006]0
svy: mean margin2007, over(npc)
lincom [margin2007]1 - [margin2007]0
svy: mean margin2008, over(npc)
lincom [margin2008]1 - [margin2008]0
svy: mean margin2009, over(npc)
lincom [margin2009]1 - [margin2009]0
svy: mean margin2010, over(npc)
lincom [margin2010]1 - [margin2010]0

mean roa2005 if npc==0 
mean roa2006 if npc==0 
mean roa2007 if npc==0 
mean roa2008 if npc==0 
mean roa2009 if npc==0 
mean roa2010 if npc==0 
mean margin2005 if npc==0 
mean margin2006 if npc==0 
mean margin2007 if npc==0 
mean margin2008 if npc==0 
mean margin2009 if npc==0
mean margin2010 if npc==0


**Save Weights**

keep gvkey weights_w1 weights_w2 weights_w3 weights_w4 
save "/Users/rorytruex/Dropbox/Replication Files/The Returns to Office in a Rubber Stamp Parliament - Entropy Weights.dta", replace


**Merge With Panel Data**

use "/Users/rorytruex/Dropbox/Returns to Office Project/Dataverse Replication File - RTO Trim Panel Data.dta"
merge m:m gvkey using "/Users/rorytruex/Dropbox/Replication Files/The Returns to Office in a Rubber Stamp Parliament - Entropy Weights.dta", generate(weights_merge)


**Estimate Fixed Effect Models for Table 4** 

xtset gvkey fyear

*2005-2010 Analysis*
xtreg roa npc fyear_ind* [aweight=weights_w1], fe vce(robust)
xtreg roa npc fyear_ind* [aweight=weights_w2], fe vce(robust)
xtreg roa npc fyear_ind* [aweight=weights_w3], fe vce(robust)
xtreg roa npc fyear_ind* [aweight=weights_w4], fe vce(robust)

xtreg margin npc fyear_ind* [aweight=weights_w1], fe vce(robust)
xtreg margin npc fyear_ind* [aweight=weights_w2], fe vce(robust)
xtreg margin npc fyear_ind* [aweight=weights_w3], fe vce(robust)
xtreg margin npc fyear_ind* [aweight=weights_w4], fe vce(robust)

*2007-2009 Analysis*
xtreg roa npc fyear_ind* if include0709==1 [aweight=weights_w1], fe vce(robust)
xtreg roa npc fyear_ind* if include0709==1 [aweight=weights_w2], fe vce(robust)
xtreg roa npc fyear_ind* if include0709==1 [aweight=weights_w3], fe vce(robust)
xtreg roa npc fyear_ind* if include0709==1 [aweight=weights_w4], fe vce(robust)

xtreg margin npc fyear_ind* if include0709==1 [aweight=weights_w1], fe vce(robust)
xtreg margin npc fyear_ind* if include0709==1 [aweight=weights_w2], fe vce(robust)
xtreg margin npc fyear_ind* if include0709==1 [aweight=weights_w3], fe vce(robust)
xtreg margin npc fyear_ind* if include0709==1 [aweight=weights_w4], fe vce(robust)


**Testing for Conditional Hypotheses**
*All calculations for Figure 3 follow formulas in Brambor et al. 2006* [See "RTOFigure3Data.csv"]

gen npcXso_portion = npc*so_portion
gen npcXrev2007 = npc*rev2007

xtreg roa npc npcXso_portion so_portion fyear_ind* [aweight=weights_w4], fe vce(robust)
matrix b=e(b)
matrix V=e(V)
scalar varb1=V[1,1]
scalar varb2=V[2,2]
scalar covb1b3=V[1,2]
display varb1
display varb2
display covb1b3

xtreg roa npc npcXrev2007 rev2007 fyear_ind* [aweight=weights_w4], fe vce(robust)
matrix b=e(b)
matrix V=e(V)
scalar varb1=V[1,1]
scalar varb2=V[2,2]
scalar covb1b3=V[1,2]
display varb1
display varb2
display covb1b3

xtreg margin npc npcXso_portion so_portion fyear_ind* [aweight=weights_w4], fe vce(robust)
matrix b=e(b)
matrix V=e(V)
scalar varb1=V[1,1]
scalar varb2=V[2,2]
scalar covb1b3=V[1,2]
display varb1
display varb2
display covb1b3

xtreg margin npc npcXrev2007 rev2007 fyear_ind* [aweight=weights_w4], fe vce(robust)
matrix b=e(b)
matrix V=e(V)
scalar varb1=V[1,1]
scalar varb2=V[2,2]
scalar covb1b3=V[1,2]
display varb1
display varb2
display covb1b3


**Analysis of Stock Prices and External Perceptions Mechanism**

use "/Users/rorytruex/Dropbox/Returns to Office Project/Dataverse Replication File - RTO Trim Panel Stock Data.dta"
merge m:m gvkey using "/Users/rorytruex/Dropbox/Replication Files/The Returns to Office in a Rubber Stamp Parliament - Entropy Weights.dta", generate(weights_merge)


*Calculate Mean PRICE for Figure 4* [See "RTOFigure3Data.csv"]
svyset [pweight=weights_w4]

svy: mean prccd, over(npcportfolio) subpop(if mydate==16112007) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==23112007) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==30112007) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==7122007) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==14122007) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==21122007) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==28122007) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==412008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==1112008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==1812008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==2512008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==122008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==522008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==1522008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==2222008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==2922008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==732008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==1432008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==2032008) 
svy: mean prccd, over(npcportfolio) subpop(if mydate==2832008) 

mean prccd if mydate==16112007, over(npcportfolio) 
mean prccd if mydate==23112007, over(npcportfolio) 
mean prccd if mydate==30112007, over(npcportfolio) 
mean prccd if mydate==7122007, over(npcportfolio) 
mean prccd if mydate==14122007, over(npcportfolio) 
mean prccd if mydate==21122007, over(npcportfolio)  
mean prccd if mydate==28122007, over(npcportfolio) 
mean prccd if mydate==412008, over(npcportfolio)  
mean prccd if mydate==1112008, over(npcportfolio) 
mean prccd if mydate==1812008, over(npcportfolio)  
mean prccd if mydate==2512008, over(npcportfolio) 
mean prccd if mydate==122008, over(npcportfolio) 
mean prccd if mydate==522008, over(npcportfolio) 
mean prccd if mydate==1522008, over(npcportfolio) 
mean prccd if mydate==2222008, over(npcportfolio)  
mean prccd if mydate==2922008, over(npcportfolio) 
mean prccd if mydate==732008, over(npcportfolio) 
mean prccd if mydate==1432008, over(npcportfolio)  
mean prccd if mydate==2032008, over(npcportfolio) 
mean prccd if mydate==2832008, over(npcportfolio) 

*Estimate Fixed Effect Models* 

gen exclude = 0
replace exclude=1 if mydate==412008
replace exclude=1 if mydate==1112008
replace exclude=1 if mydate==1812008
replace exclude=1 if mydate==2512008
replace exclude=1 if mydate==122008
replace exclude=1 if mydate==522008
replace exclude=1 if mydate==1522008
replace exclude=1 if mydate==2222008
replace exclude=1 if mydate==2922008

gen exclude_narrow = exclude
replace exclude_narrow=1 if mydate==16112007
replace exclude_narrow=1 if mydate==23112007
replace exclude_narrow=1 if mydate==30112007
replace exclude_narrow=1 if mydate==7122007
replace exclude_narrow=1 if mydate==14122007
replace exclude_narrow=1 if mydate==21122007
replace exclude_narrow=1 if mydate==1432008
replace exclude_narrow=1 if mydate==2032008
replace exclude_narrow=1 if mydate==2832008

*Full analysis period*
xtreg prccd npctreatment md* [aweight=weights_w1] if exclude~=1, fe vce(robust)
xtreg prccd npctreatment md* [aweight=weights_w2] if exclude~=1, fe vce(robust)
xtreg prccd npctreatment md* [aweight=weights_w3] if exclude~=1, fe vce(robust)
xtreg prccd npctreatment md* [aweight=weights_w4] if exclude~=1, fe vce(robust)

*Narrow analysis period*
xtreg prccd npctreatment md* [aweight=weights_w1] if exclude_narrow~=1, fe vce(robust)
xtreg prccd npctreatment md* [aweight=weights_w2] if exclude_narrow~=1, fe vce(robust)
xtreg prccd npctreatment md* [aweight=weights_w3] if exclude_narrow~=1, fe vce(robust)
xtreg prccd npctreatment md* [aweight=weights_w4] if exclude_narrow~=1, fe vce(robust)
